<?php

declare(strict_types=1);

namespace Dedi\SyliusDpdPickUpPlugin\Service;

use Dedi\SyliusDpdPickUpPlugin\Entity\ShippingMethodInterface;
use Sylius\Component\Core\Customer\CustomerAddressAdderInterface;
use Sylius\Component\Core\Customer\OrderAddressesSaverInterface;
use Sylius\Component\Core\Model\AddressInterface;
use Sylius\Component\Core\Model\CustomerInterface;
use Sylius\Component\Core\Model\OrderInterface;
use Sylius\Component\Core\Model\ShipmentInterface;

/**
 * This service decorates the class Sylius\Component\Core\Customer\CustomerOrderAddressesSaver
 * It does not save shipping addresses to the customer address book when the shipping method is a DPD PickUp method.
 */
final class CustomerOrderAddressesSaver implements OrderAddressesSaverInterface
{
    /** @var CustomerAddressAdderInterface */
    private $addressAdder;

    public function __construct(CustomerAddressAdderInterface $addressAdder)
    {
        $this->addressAdder = $addressAdder;
    }

    public function saveAddresses(OrderInterface $order): void
    {
        /** @var CustomerInterface $customer */
        $customer = $order->getCustomer();
        if (null === $customer->getUser()) {
            return;
        }

        $this->addAddress($customer, $order->getBillingAddress());

        /** @var ShipmentInterface $shipment */
        $shipment = $order->getShipments()->first();
        /** @var ShippingMethodInterface $method */
        $method = $shipment->getMethod();

        if (!$method->isDpdPickUp()) {
            $this->addAddress($customer, $order->getShippingAddress());
        }
    }

    private function addAddress(CustomerInterface $customer, ?AddressInterface $address): void
    {
        if (null !== $address) {
            $this->addressAdder->add($customer, clone $address);
        }
    }
}
